﻿/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'fa', {
	auto: 'خودکار',
	bgColorTitle: 'رنگ پس​زمینه',
	colors: {
		'000': 'سیاه',
		'800000': 'خرمایی',
		'8B4513': 'قهوه​ای شکلاتی',
		'2F4F4F': 'ارغوانی مایل به خاکستری',
		'008080': 'آبی مایل به خاکستری',
		'000080': 'آبی سیر',
		'4B0082': 'نیلی',
		'696969': 'خاکستری تیره',
		B22222: 'آتش آجری',
		A52A2A: 'قهوه​ای',
		DAA520: 'میله​ی طلایی',
		'006400': 'سبز تیره',
		'40E0D0': 'فیروزه​ای',
		'0000CD': 'آبی روشن',
		'800080': 'ارغوانی',
		'808080': 'خاکستری',
		F00: 'قرمز',
		FF8C00: 'نارنجی پررنگ',
		FFD700: 'طلایی',
		'008000': 'سبز',
		'0FF': 'آبی مایل به سبز',
		'00F': 'آبی',
		EE82EE: 'بنفش',
		A9A9A9: 'خاکستری مات',
		FFA07A: 'صورتی کدر روشن',
		FFA500: 'نارنجی',
		FFFF00: 'زرد',
		'00FF00': 'فسفری',
		AFEEEE: 'فیروزه​ای رنگ پریده',
		ADD8E6: 'آبی کمرنگ',
		DDA0DD: 'آلویی',
		D3D3D3: 'خاکستری روشن',
		FFF0F5: 'بنفش کمرنگ',
		FAEBD7: 'عتیقه سفید',
		FFFFE0: 'زرد روشن',
		F0FFF0: 'عسلی',
		F0FFFF: 'لاجوردی',
		F0F8FF: 'آبی براق',
		E6E6FA: 'بنفش کمرنگ',
		FFF: 'سفید',
		'1ABC9C': 'فیروزه ای پررنگ',
		'2ECC71': 'سبز زمردی',
		'3498DB': 'آبی روشن',
		'9B59B6': 'ارغوانی',
		'4E5F70': 'آبی خاکستری',
		'F1C40F': 'زرد تازه',
		'16A085': 'فیروزه ای تیره',
		'27AE60': 'سبز زمردی تیره',
		'2980B9': 'آبی پر رنگ',
		'8E44AD': 'بنفش تیره',
		'2C3E50': 'آبی اشباع شده',
		'F39C12': 'نارنجی',
		'E67E22': 'هویجی',
		'E74C3C': 'قرمز روشن',
		'ECF0F1': 'نقره ای روشن',
		'95A5A6': 'آبی خاکستری روشن',
		'DDD': 'خاکستری روشن',
		'D35400': 'کدو حلوایی',
		'C0392B': 'قرمز پررنگ',
		'BDC3C7': 'نقره ای',
		'7F8C8D': 'فیروزه ای خاکستری',
		'999': 'خاکستری تیره'
	},
	more: 'رنگ​های بیشتر...',
	panelTitle: 'رنگها',
	textColorTitle: 'رنگ متن'
} );
